using System;
using System.Collections.Generic;
using System.Collections;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Mod
{
    public class BreatheBehaviour : MonoBehaviour
    {
        public float lungEfficiency = 1f;
        public float breathTime = 1f;
        public float breathSize = .05f;
        public float breathRandomization = 0f;
        public bool regen;
        public float regenTime = 5f;
        public LimbBehaviour limb;
        public GasBehaviour currentGas;

        public enum ExposureLevel{Mild, Moderate, Severe}

        void Start()
        {
            StartCoroutine(ContinuousBreathe());
            //StartCoroutine(Regen());
        }
        void Update()
        {
            if (lungEfficiency < 1)
            {
                regenTime -= Time.deltaTime;
                if (regenTime <= 0)
                    regen = true;
                // fastest suffocation can happen is 180 seconds
                float oxygenLossTime = (240 * lungEfficiency);
                oxygenLossTime = Mathf.Clamp(oxygenLossTime, 6f, 360f);

                limb.Person.OxygenLevel -= Time.deltaTime / oxygenLossTime;
            }
        }
        public IEnumerator Regen()
        {
            while (1 == 1)
            {
                if (lungEfficiency < 1 && regen)
                    lungEfficiency += Time.deltaTime / 2;
                if (lungEfficiency >= 1)
                {
                    regen = false;
                    regenTime = 5f;
                }
                yield return null;
            }
        }
        public IEnumerator ContinuousBreathe()
        {
            while (1 == 1)
            {
                if (limb.Health > 0)
                    Inhale();
                yield return new WaitForSeconds(breathTime);
            }
        }
        public void Inhale()
        {
            if (currentGas != null)
            {
                GasEffects(currentGas.prop.type, currentGas);
                regenTime = 5f;
                regen = false;
            }
        }
        public void GasEffects(GasProperties.GasType type, GasBehaviour gas)
        {
            float intake = gas.concentration;
            // Maximum intake will cause the most damage.
            lungEfficiency -= gas.prop.lungDamage * intake;
            limb.Person.Consciousness -= gas.prop.consciousnessDamage * intake;
            limb.BaseStrength -= gas.prop.strengthDamage * intake;
            breathRandomization += intake / 2;

            // Simply breathing in gas will cause them to lose oxygen.
            float initalOxygenLoss = intake / 20;
            initalOxygenLoss = Mathf.Clamp(initalOxygenLoss, 0, breathSize);
            limb.Person.OxygenLevel -= initalOxygenLoss;
        }
    }
}